@@ -41,6 +41,7 @@
 #include <KSharedConfig>
 #include <KStandardGuiItem>
 #include <KTitleWidget>
+#include <Kirigami/Units>
 
 #include <KActivities/ResourceInstance>
 
@@ -62,7 +63,8 @@ protected:
 CustomTitle::CustomTitle(QWidget *parent)
     : KTitleWidget(parent)
 {
-    setContentsMargins(style()->pixelMetric(QStyle::PM_LayoutLeftMargin),
+    // Use the same left margin as QML titles for consistency (Kirigami/AbstractPageHeader.qml)
+    setContentsMargins(Kirigami::Units().gridUnit(),
                        style()->pixelMetric(QStyle::PM_LayoutTopMargin),
                        style()->pixelMetric(QStyle::PM_LayoutRightMargin),
                        style()->pixelMetric(QStyle::PM_LayoutBottomMargin));
@@ -319,18 +321,18 @@ bool ModuleView::resolveChanges(KCModuleProxy *currentProxy)
     }
 
     // Let the user decide
-    const int queryUser = KMessageBox::warningYesNoCancel(this,
-                                                          i18n("The settings of the current module have changed.\n"
-                                                               "Do you want to apply the changes or discard them?"),
-                                                          i18n("Apply Settings"),
-                                                          KStandardGuiItem::apply(),
-                                                          KStandardGuiItem::discard(),
-                                                          KStandardGuiItem::cancel());
+    const int queryUser = KMessageBox::warningTwoActionsCancel(this,
+                                                               i18n("The settings of the current module have changed.\n"
+                                                                    "Do you want to apply the changes or discard them?"),
+                                                               i18n("Apply Settings"),
+                                                               KStandardGuiItem::apply(),
+                                                               KStandardGuiItem::discard(),
+                                                               KStandardGuiItem::cancel());
 
     switch (queryUser) {
-    case KMessageBox::Yes:
+    case KMessageBox::PrimaryAction:
         return moduleSave(currentProxy);
-    case KMessageBox::No:
+    case KMessageBox::SecondaryAction:
         currentProxy->load();
         return true;
     case KMessageBox::Cancel:
@@ -439,7 +441,7 @@ void ModuleView::activeModuleChanged(KPageWidgetItem *current, KPageWidgetItem *
                                     style()->pixelMetric(QStyle::PM_LayoutBottomMargin));
     d->mPageWidget->layout()->setSpacing(0);
     if (auto titleWidget = qobject_cast<KTitleWidget *>(d->mPageWidget->pageHeader())) {
-        titleWidget->layout()->setContentsMargins(style()->pixelMetric(QStyle::PM_LayoutLeftMargin),
+        titleWidget->layout()->setContentsMargins(Kirigami::Units().gridUnit(),
                                                   style()->pixelMetric(QStyle::PM_LayoutRightMargin),
                                                   style()->pixelMetric(QStyle::PM_LayoutRightMargin),
                                                   style()->pixelMetric(QStyle::PM_LayoutBottomMargin));
@@ -598,3 +600,12 @@ void ModuleView::setActiveModule(const QString &moduleName)
         }
     }
 }
+
+KPluginMetaData ModuleView::activeModuleMetadata() const
+{
+    KCModuleProxy *activeModule = d->mPages.value(d->mPageWidget->currentPage());
+    if (!activeModule) {
+        return {};
+    }
+    return activeModule->metaData();
+}
